pub fn generate_sshkey(
key_algorithm: KeyAlgorithm,
) -> Result<SshKeyData, KeyGenerationError>Expand description
Generate a new SSH key pair, for the provided key algorithm, returning an SshKeyData struct containing the private key, public key, and key fingerprint, with the private key in OpenSSH format.